@@ -844,21 +844,15 @@ draw_color_each_monitor (MateBG    *bg,
 			 GdkPixbuf *dest,
 			 GdkScreen *screen)
 {
-#if GTK_CHECK_VERSION (3, 22, 0)
 	GdkDisplay *display;
-#endif
 	GdkRectangle rect;
 	gint num_monitors;
 	int monitor;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
 	display = gdk_screen_get_display (screen);
 	num_monitors = gdk_display_get_n_monitors (display);
-#else
-	num_monitors = gdk_screen_get_n_monitors (screen);
-#endif
 	for (monitor = 0; monitor < num_monitors; monitor++) {
-		gdk_screen_get_monitor_geometry (screen, monitor, &rect);
+		gdk_monitor_get_geometry (gdk_display_get_monitor (display, monitor), &rect);
 		draw_color_area (bg, dest, &rect);
 	}
 }
@@ -1029,21 +1023,17 @@ draw_each_monitor (MateBG    *bg,
 		   GdkPixbuf *dest,
 		   GdkScreen *screen)
 {
-#if GTK_CHECK_VERSION (3, 22, 0)
 	GdkDisplay *display;
 
 	display = gdk_screen_get_display (screen);
 	gint num_monitors = gdk_display_get_n_monitors (display);
-#else
-	gint num_monitors = gdk_screen_get_n_monitors (screen);
-#endif
 	gint monitor = 0;
 
 	for (; monitor < num_monitors; monitor++) {
 		GdkRectangle rect;
 		GdkPixbuf *pixbuf;
 
-		gdk_screen_get_monitor_geometry (screen, monitor, &rect);
+		gdk_monitor_get_geometry (gdk_display_get_monitor (display, monitor), &rect);
 
 		pixbuf = get_pixbuf_for_size (bg, monitor, rect.width, rect.height);
 		if (pixbuf) {
@@ -1463,8 +1453,8 @@ mate_bg_get_surface_from_root (GdkScreen *screen)
 		gdk_error_trap_pop_ignored ();
 	}
 
-	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-				 &width, &height);
+	width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
+	height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
 
 	if (source_pixmap) {
 		surface = cairo_surface_create_similar (source_pixmap,
@@ -2109,14 +2099,10 @@ scale_thumbnail (MateBGPlacement placement,
 	if (get_thumb_annotations (thumb, &o_width, &o_height)		||
 	    (filename && get_original_size (filename, &o_width, &o_height))) {
 
-		int scr_height;
-		int scr_width;
+		int scr_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
+		int scr_width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
 		int thumb_width = gdk_pixbuf_get_width (thumb);
 		int thumb_height = gdk_pixbuf_get_height (thumb);
-
-		gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-					 &scr_width, &scr_height);
-
 		double screen_to_dest = fit_factor (scr_width, scr_height,
 						    dest_width, dest_height);
 		double thumb_to_orig  = fit_factor (thumb_width, thumb_height,
