@@ -121,9 +121,8 @@ get_work_area (MateRRLabeler *labeler,
 	/* Defaults in case of error */
 	rect->x = 0;
 	rect->y = 0;
-
-	gdk_window_get_geometry (gdk_screen_get_root_window (labeler->priv->screen), NULL, NULL,
-				 &rect->width, &rect->height);
+	rect->width = WidthOfScreen (gdk_x11_screen_get_xscreen (labeler->priv->screen));
+	rect->height = HeightOfScreen (gdk_x11_screen_get_xscreen (labeler->priv->screen));
 
 	if (workarea == None)
 		return FALSE;
@@ -364,13 +363,11 @@ position_window (MateRRLabeler  *labeler,
 {
 	GdkRectangle    workarea;
 	GdkRectangle    monitor;
-	int             monitor_num;
+	GdkMonitor     *monitor_num;
 
 	get_work_area (labeler, &workarea);
-	monitor_num = gdk_screen_get_monitor_at_point (labeler->priv->screen, x, y);
-	gdk_screen_get_monitor_geometry (labeler->priv->screen,
-                                         monitor_num,
-                                         &monitor);
+	monitor_num = gdk_display_get_monitor_at_point (gdk_screen_get_display (labeler->priv->screen), x, y);
+	gdk_monitor_get_geometry (monitor_num, &monitor);
 	gdk_rectangle_intersect (&monitor, &workarea, &workarea);
 
 	gtk_window_move (GTK_WINDOW (window), workarea.x, workarea.y);
